# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.chat_history_query_dto import ChatHistoryQueryDTO  # noqa: E501

class TestChatHistoryQueryDTO(unittest.TestCase):
    """ChatHistoryQueryDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatHistoryQueryDTO:
        """Test ChatHistoryQueryDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatHistoryQueryDTO`
        """
        model = ChatHistoryQueryDTO()  # noqa: E501
        if include_optional:
            return ChatHistoryQueryDTO(
                where = xingchen.models.chat_history_query_where.ChatHistoryQueryWhere(
                    character_id = '', 
                    session_id = '', 
                    start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    message_ids = [
                        ''
                        ], ),
                order_by = [
                    ''
                    ],
                page_num = 56,
                page_size = 56
            )
        else:
            return ChatHistoryQueryDTO(
        )
        """

    def testChatHistoryQueryDTO(self):
        """Test ChatHistoryQueryDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
